@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 0.1.6   2012/11/01
+ * Version: 0.1.7   2012/12/25
  */
 
 #ifndef _LINUX_CAITSITH_H
@@ -29,7 +29,11 @@ struct sock;
 struct sk_buff;
 struct msghdr;
 struct pid_namespace;
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(3, 8, 0)
+int search_binary_handler(struct linux_binprm *bprm);
+#else
 int search_binary_handler(struct linux_binprm *bprm, struct pt_regs *regs);
+#endif
 
 #ifdef CONFIG_CAITSITH
 
@@ -133,8 +137,12 @@ struct caitsith_operations {
 				   struct dentry *dentry);
 	int (*sigqueue_permission) (pid_t pid, int sig);
 	int (*tgsigqueue_permission) (pid_t tgid, pid_t pid, int sig);
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(3, 8, 0)
+	int (*search_binary_handler) (struct linux_binprm *bprm);
+#else
 	int (*search_binary_handler) (struct linux_binprm *bprm,
 				      struct pt_regs *regs);
+#endif
 #ifdef CONFIG_CAITSITH_USE_EXTERNAL_TASK_SECURITY
 	int (*alloc_task_security) (const struct task_struct *task);
 	void (*free_task_security) (const struct task_struct *task);
@@ -353,12 +361,23 @@ static inline int ccs_chmod_permission(struct dentry *dentry,
 	return func ? func(dentry, mnt, mode) : 0;
 }
 
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(3, 8, 0)
+
+static inline int ccs_search_binary_handler(struct linux_binprm *bprm)
+{
+	return caitsith_ops.search_binary_handler(bprm);
+}
+
+#else
+
 static inline int ccs_search_binary_handler(struct linux_binprm *bprm,
 					    struct pt_regs *regs)
 {
 	return caitsith_ops.search_binary_handler(bprm, regs);
 }
 
+#endif
+
 #else
 
 static inline int ccs_chroot_permission(struct path *path)
@@ -518,6 +537,15 @@ static inline int ccs_chmod_permission(struct dentry *dentry,
 	return 0;
 }
 
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(3, 8, 0)
+
+static inline int ccs_search_binary_handler(struct linux_binprm *bprm)
+{
+	return search_binary_handler(bprm);
+}
+
+#else
+
 static inline int ccs_search_binary_handler(struct linux_binprm *bprm,
 					    struct pt_regs *regs)
 {
@@ -526,6 +554,8 @@ static inline int ccs_search_binary_handler(struct linux_binprm *bprm,
 
 #endif
 
+#endif
+
 #ifdef CONFIG_CAITSITH_USE_EXTERNAL_TASK_SECURITY
 
 static inline int ccs_alloc_task_security(const struct task_struct *task)
